/**
 * 公共方法合集
 */
type _typeObj = { [anyKey: string]: any }
export class Utils {
  /**
   * 防抖
   */
  static debounced(_func: Function, _delay = 500, _immediate = false) {
    let timer: NodeJS.Timeout;
    return (...args: any) => {
      if (_immediate) {
        _func.apply(this, args);
        _immediate = false;
        return;
      }
      clearTimeout(timer);
      timer = setTimeout(() => {
        _func.apply(this, args);
      }, _delay);
    };
  }

  /**
   * 节流
   */
  static throttle(_func: Function, _delay = 500) {
    let flag = true;
    let timer: NodeJS.Timeout;
    return (...args: any) => {
      if (flag) {
        _func.apply(this, args); // 确保引用函数的指向正确，而且函数的参数也不变
        flag = false;
        clearTimeout(timer);
        timer = setTimeout(() => {
          flag = true;
        }, _delay);
      }
    };
  }

  /**
   * @param deepClone 深拷贝
   * @param _object 如果不传返回为空对象 必须是js的{}对象
   * @param _obj 可选 返回传入的@param _object 必须是js的{}对象,
   */
  static deepClone(_object: _typeObj, _obj: _typeObj = {}): _typeObj {
    return (...args: any) => {
      if (!(Object.prototype === Object.getPrototypeOf(_object))) {
        return new Error("传入参数***_object***类型错误");
      }
      for (let key in _object) {
        if (Object.prototype === Object.getPrototypeOf(_object[key])) {
          _obj[key] = Utils.deepClone(_object[key]);
        } else {
          _obj[key] = _object[key];
        }
      }
      return _obj;
    };
  }
}
