import { ApiRequest } from "./ApiRequest";
import { Randomizer } from "../security";

/**
 * 表示一个发给微服务API的原始请求消息，遵循JSON-RPC协议规范：https://wiki.geekdream.com/Specification/json-rpc_2.0.html
 */
export class ApiRequestMessage<TRequest extends ApiRequest> {
  // #region Constructors

  constructor() {
    this.jsonrpc = "2.0";
    this.method = "";
    this.id = Randomizer.generateString(16);
  }

  // #endregion

  // #region 协议属性

  /**
   * 指定JSON-RPC协议版本的字符串，必须准确写为“2.0”。
   */
  jsonrpc: string;

  /**
   * 包含所要调用方法名称的字符串。
   */
  method: string;

  /**
   * 调用方法所需要的结构化参数值。
   */
  params: TRequest | undefined;

  /**
   * 已建立客户端的唯一标识id。
   */
  id: string;

  // #endregion
}
