import { ApiResponse } from "./ApiResponse";
import { Randomizer } from "../security";
import { ApiResponseError } from "..";

/**
 * 表示一个从微服务API返回的原始响应消息，遵循JSON-RPC协议规范：https://wiki.geekdream.com/Specification/json-rpc_2.0.html
 */
export class ApiResponseMessage<TResponse extends ApiResponse> {
  // #region Constructors

  constructor() {
    this.jsonrpc = "2.0";
    this.id = Randomizer.generateString(16);
  }

  // #endregion

  /**
   * 指定JSON-RPC协议版本的字符串，必须准确写为“2.0”。
   */
  jsonrpc: string;

  /**
   * 在成功时返回结果，失败时为空。
   */
  result: TResponse | undefined;

  /**
   * 在失败时返回错误，成功时为空。
   */
  error: ApiResponseError | undefined;

  /**
   * 已建立客户端的唯一标识id。
   */
  id: string | undefined;
}
