/**
 * 定义API响应错误代码。
 */
export enum ApiResponseErrorCode {
  /**
   * 服务端接收到无效的json，该错误发送于服务器尝试解析json文本。
   */
  PARSE_ERROR = -32700,

  /**
   * 发送的json不是一个有效的请求对象。
   */
  INVALID_REQUEST = -32600,

  /**
   * 该方法不存在或无效。
   */
  METHOD_NOT_FOUND = -32601,

  /**
   * 无效的方法参数。
   */
  INVALID_PARAMS = -32602,

  /**
   * JSON-RPC内部错误。
   */
  INTERNAL_ERROR = -32603,

  /**
   * 预留用于自定义的应用程序错误起始值。
   */
  SERVER_ERROR_BEGIN = -32000,

  /**
   * 未登录
   */
  AUTH_NOT_LOGIN = -32001,

  /**
   * 登录信息过期
   */
  AUTH_EXPIRED = -32002,

  /**
   * 参数为空
   */
  PARAM_EMPTY = -32010,

  /**
   * 参数类型错误
   */
  PARAMETER_ERROR = -32011,

  /**
   * java接口报错
   */
  JAVA_BUSINESS_ERROR = -32020,

  /**
   * node业务错误
   */
  NODE_BUSINESS_ERROR = -32021,

  /**
   * 预留用于自定义的应用程序错误终止值。
   */
  SERVER_ERROR_END = -32099,

  /**
   * 未知错误。
   */
  UNKNOWN = -1,

  /**
   * 应用程序错误起始值。
   */
  APPLICATION_BEGIN = 1
}
