export class DateUtils {
  /**
   * @description 根据时间戳获取字符串日期 时间
   * @param date {number} 时间戳
   * @param hasTime {boolean} 是否格式化时间
   * @returns {string} 格式化后的日期时间字符串
   */
  static dataFormat(date: number, hasTime?: boolean): string {
    const dateObj = new Date(date);
    const YY = dateObj.getFullYear() + "-";
    const MM = (dateObj.getMonth() + 1 < 10 ? "0" + (dateObj.getMonth() + 1) : dateObj.getMonth() + 1) + "-";
    const DD = dateObj.getDate() < 10 ? "0" + dateObj.getDate() : dateObj.getDate();
    const dateStr = YY + MM + DD;
    if (hasTime) {
      const hh = (dateObj.getHours() < 10 ? "0" + dateObj.getHours() : dateObj.getHours()) + ":";
      const mm = (dateObj.getMinutes() < 10 ? "0" + dateObj.getMinutes() : dateObj.getMinutes()) + ":";
      const ss = dateObj.getSeconds() < 10 ? "0" + dateObj.getSeconds() : dateObj.getSeconds();
      return `${dateStr} ${hh + mm + ss}`;
    }
    return dateStr;
  }

  /**
   * @description 根据时间戳获取字符串时间
   * @param date {number} 时间戳
   * @returns {string} 格式化后的时间字符串
   */
  static timeFormat(date: number): string {
    const dateObj = new Date(date);
    const hh = (dateObj.getHours() < 10 ? "0" + dateObj.getHours() : dateObj.getHours()) + ":";
    const mm = (dateObj.getMinutes() < 10 ? "0" + dateObj.getMinutes() : dateObj.getMinutes()) + ":";
    const ss = dateObj.getSeconds() < 10 ? "0" + dateObj.getSeconds() : dateObj.getSeconds();
    return `${hh + mm + ss}`;
  }

  /**
   * @description 根据当前时间获取本月的第一天时间
   * @param date { number } 时间戳
   * @returns { string } 格式化后的日期时间字符串
   */
  static getFirstDay(date: number): string {
    const oDate = new Date(date);
    let month: string | number = oDate.getMonth() + 1;
    if (month < 9) {
      month = "0" + month;
    }
    return oDate.getFullYear() + "-" + month + "-01";
  }

  /**
   * @description 根据当前时间获取下个月的第一天时间
   * @param date { number } 时间戳
   * @returns { string } 格式化后的日期时间字符串
   */
  static getFirstDayOfNextMonth(date: number): string {
    const oDate = new Date(date);
    let year = oDate.getFullYear();
    let month: string | number = oDate.getMonth() + 1;
    if (month === 12) {
      month = 1;
      year += 1;
    } else {
      month += 1;
    }
    if (month < 9) {
      month = "0" + month;
    }
    return year + "-" + month + "-01";
  }
  // 更多日期 时间格式化需求可以引入moment 库再做封装
}
